get_growth_post_prob: Posterior probability of sex being female based on growth
Description
get_growth_post_prob returns the probability of
the observation(s) arising from the female component given a set of growth parameters
and an assumed distribution (normal or lognormal). The component probability is
given by Bayes' theorem. Used internally.